from django.contrib import admin
from django.urls import path
from enumfields.admin import EnumFieldListFilter

from arkindex.images.models import Image, ImageServer
from arkindex.images.views import ImageServerMergeView, ImageServerSplitView


@admin.register(ImageServer)
class ImageServerAdmin(admin.ModelAdmin):
    list_display = ("display_name", "url")
    search_fields = ("url", )

    def get_urls(self):
        # Give views access to this ModelAdmin instance
        ImageServerMergeView.model_admin = self
        ImageServerSplitView.model_admin = self

        urls = super().get_urls()
        return [
            path(
                "<id>/merge/",
                self.admin_site.admin_view(ImageServerMergeView.as_view()),
                name="images_imageserver_merge",
            ),
            path(
                "<id>/split/",
                self.admin_site.admin_view(ImageServerSplitView.as_view()),
                name="images_imageserver_split",
            )
        ] + urls

    def save_model(self, request, instance, form, change):
        """
        When updating the local ImageServer, erase the cached server
        so that its properties are reloaded
        """
        super().save_model(request, instance, form, change)
        # change is True if updating an existing server
        if change and instance.id == ImageServer.objects.local.id:
            del ImageServer.objects.local


@admin.register(Image)
class ImageAdmin(admin.ModelAdmin):
    list_display = ("path", "server", "width", "height", "status")
    list_filter = (
        ("server", admin.RelatedFieldListFilter),
        ("status", EnumFieldListFilter),
    )
    fields = ("id", "server", "path", "width", "height", "status")
    search_fields = ("path", )
    readonly_fields = ("id", )
