# Generated by Django 4.1.7 on 2023-05-29 11:49

import uuid

import django.contrib.postgres.fields.hstore
import django.core.validators
import django.db.models.deletion
import enumfields.fields
from django.contrib.postgres.operations import HStoreExtension
from django.db import migrations, models

import arkindex.ponos.models
import arkindex.project.fields
import arkindex.project.validators


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        HStoreExtension(),
        migrations.CreateModel(
            name="Agent",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("public_key", models.TextField()),
                ("hostname", models.SlugField(db_index=False, max_length=64)),
                ("cpu_cores", models.PositiveSmallIntegerField(validators=[django.core.validators.MinValueValidator(1)])),
                ("cpu_frequency", models.BigIntegerField(validators=[django.core.validators.MinValueValidator(1)])),
                ("ram_total", models.BigIntegerField(validators=[django.core.validators.MinValueValidator(1)])),
                ("cpu_load", models.FloatField(blank=True, null=True)),
                ("ram_load", models.FloatField(blank=True, null=True)),
                ("last_ping", models.DateTimeField(editable=False)),
            ],
        ),
        migrations.CreateModel(
            name="Artifact",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("path", models.CharField(max_length=500)),
                ("size", models.BigIntegerField(validators=[django.core.validators.MinValueValidator(1), arkindex.project.validators.MaxValueValidator(arkindex.ponos.models.artifact_max_size)])),
                ("content_type", models.CharField(default="application/octet-stream", max_length=250)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
            ],
            options={
                "ordering": ("task", "path"),
            },
        ),
        migrations.CreateModel(
            name="Farm",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=250)),
                ("seed", models.CharField(default=arkindex.ponos.models.generate_seed, max_length=64, unique=True, validators=[django.core.validators.RegexValidator("^[0-9a-f]{64}$")])),
            ],
        ),
        migrations.CreateModel(
            name="GPU",
            fields=[
                ("id", models.UUIDField(primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=250)),
                ("index", models.PositiveIntegerField()),
                ("ram_total", models.BigIntegerField(validators=[django.core.validators.MinValueValidator(1)])),
                ("agent", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="gpus", to="ponos.agent")),
            ],
        ),
        migrations.CreateModel(
            name="Secret",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=250, unique=True)),
                ("nonce", models.BinaryField(default=arkindex.ponos.models.gen_nonce, max_length=16)),
                ("content", models.BinaryField(editable=True)),
            ],
        ),
        migrations.CreateModel(
            name="Workflow",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("finished", models.DateTimeField(blank=True, null=True)),
                ("farm", models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name="workflows", to="ponos.farm")),
            ],
            options={
                "ordering": ("-updated",),
            },
        ),
        migrations.CreateModel(
            name="Task",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ("run", models.PositiveIntegerField()),
                ("depth", models.PositiveIntegerField()),
                ("slug", models.CharField(max_length=250, validators=[django.core.validators.MinLengthValidator(1)])),
                ("priority", models.PositiveIntegerField(default=10)),
                ("state", enumfields.fields.EnumField(default="unscheduled", enum=arkindex.ponos.models.State, max_length=20)),
                ("tags", arkindex.project.fields.ArrayField(base_field=models.CharField(max_length=250), blank=True, default=list, size=16)),
                ("image", models.CharField(max_length=250)),
                ("shm_size", models.CharField(blank=True, editable=False, max_length=80, null=True)),
                ("command", models.TextField(blank=True, null=True)),
                ("env", django.contrib.postgres.fields.hstore.HStoreField(default=dict)),
                ("has_docker_socket", models.BooleanField(default=False)),
                ("requires_gpu", models.BooleanField(default=False)),
                ("container", models.CharField(blank=True, max_length=64, null=True)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("expiry", models.DateTimeField(default=arkindex.ponos.models.expiry_default)),
                ("extra_files", django.contrib.postgres.fields.hstore.HStoreField(default=dict, blank=True)),
                ("token", models.CharField(default=arkindex.ponos.models.token_default, max_length=52, unique=True)),
                ("agent", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name="tasks", to="ponos.agent")),
                ("gpu", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name="tasks", to="ponos.gpu")),
                ("image_artifact", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name="tasks_using_image", to="ponos.artifact")),
                ("parents", models.ManyToManyField(related_name="children", to="ponos.task")),
                ("workflow", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="tasks", to="ponos.workflow")),
            ],
            options={
                "ordering": ("workflow", "run", "depth", "slug"),
            },
        ),
        migrations.AddField(
            model_name="artifact",
            name="task",
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="artifacts", to="ponos.task"),
        ),
        migrations.AddField(
            model_name="agent",
            name="farm",
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to="ponos.farm"),
        ),
        migrations.AddConstraint(
            model_name="workflow",
            constraint=models.CheckConstraint(condition=models.Q(("finished", None), ("finished__gte", models.F("created")), _connector="OR"), name="ponos_workflow_finished_after_created"),
        ),
        migrations.AddConstraint(
            model_name="task",
            constraint=models.UniqueConstraint(models.F("gpu"), condition=models.Q(("state__in", (arkindex.ponos.models.State["Unscheduled"], arkindex.ponos.models.State["Pending"], arkindex.ponos.models.State["Running"], arkindex.ponos.models.State["Stopping"]))), name="unique_gpu_on_active_tasks"),
        ),
        migrations.AlterUniqueTogether(
            name="task",
            unique_together={("workflow", "run", "slug")},
        ),
        migrations.AlterUniqueTogether(
            name="gpu",
            unique_together={("agent_id", "index")},
        ),
        migrations.AlterUniqueTogether(
            name="artifact",
            unique_together={("task", "path")},
        ),
    ]
