# Generated by Django 4.1.7 on 2023-10-06 14:09

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models
from django.utils import timezone

TZ_NOW = timezone.now()


def update_worker_timestamps(apps, schema):
    """Set the worker timestamps depending on their revision. Django does not allows
    to update the fields from the related table using F(), so we use a subquery here.
    """
    WorkerVersion = apps.get_model("process", "WorkerVersion")
    Revision = apps.get_model("process", "Revision")
    revision_query = Revision.objects.filter(id=models.OuterRef("revision_id"))[:1]
    WorkerVersion.objects.update(
        created=models.Subquery(revision_query.values("created")),
        updated=models.Subquery(revision_query.values("updated")),
    )


class Migration(migrations.Migration):

    dependencies = [
        ("process", "0019_docker_image_tag"),
    ]

    operations = [
        migrations.AddField(
            model_name="workerversion",
            name="created",
            field=models.DateTimeField(auto_now_add=True, default=TZ_NOW),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="workerversion",
            name="updated",
            field=models.DateTimeField(auto_now=True, default=TZ_NOW),
            preserve_default=False,
        ),
        migrations.RunPython(
            update_worker_timestamps,
            reverse_code=migrations.RunPython.noop,
            elidable=True,
        ),
        migrations.AddField(
            model_name="workerversion",
            name="version",
            field=models.PositiveIntegerField(
                blank=True,
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
            ),
        ),
        migrations.AlterField(
            model_name="worker",
            name="repository",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="workers",
                to="process.repository",
            ),
        ),
        migrations.AlterField(
            model_name="workerversion",
            name="revision",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="versions",
                to="process.revision",
            ),
        ),
        migrations.AlterUniqueTogether(
            name="workerversion",
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name="workerversion",
            constraint=models.CheckConstraint(
                condition=models.Q(("revision__isnull", True), ("version__isnull", True), _connector="XOR"),
                name="workerversion_revision_xor_version",
            ),
        ),
        migrations.AddConstraint(
            model_name="workerversion",
            constraint=models.UniqueConstraint(
                condition=models.Q(("revision__isnull", False)),
                fields=("worker", "revision"),
                name="workerversion_unique_revision",
            ),
        ),
        migrations.AddConstraint(
            model_name="workerversion",
            constraint=models.UniqueConstraint(
                condition=models.Q(("version__isnull", False)),
                fields=("worker", "version"),
                name="workerversion_unique_version"
            ),
        ),
        migrations.AlterUniqueTogether(
            name="worker",
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name="worker",
            constraint=models.UniqueConstraint(
                condition=models.Q(("repository__isnull", False)),
                fields=("slug", "repository"),
                name="workerversion_unique_slug_per_repo",
            ),
        ),
        migrations.AddConstraint(
            model_name="worker",
            constraint=models.UniqueConstraint(
                models.F("slug"),
                condition=models.Q(("repository__isnull", True)),
                name="workerversion_unique_slug_local",
            ),
        ),
    ]
