from django.contrib import admin
from enumfields.admin import EnumFieldListFilter

from arkindex.project.admin import ArchivedListFilter
from arkindex.training.models import Dataset, DatasetSet, Model, ModelVersion


@admin.register(Model)
class ModelAdmin(admin.ModelAdmin):
    list_display = ("name", "created", "archived")
    list_filter = (ArchivedListFilter, )
    search_fields = ("name", "description", )
    fields = ("name", "description", "public", "archived", "compatible_workers")


@admin.register(ModelVersion)
class ModelVersionAdmin(admin.ModelAdmin):
    list_display = ("id", "model", "tag", "size", "state")
    list_filter = ("model__name", ("state", EnumFieldListFilter), )
    fields = ("model", "parent", "description", "state", "tag", "hash", "archive_hash", "size", "configuration",)
    readonly_fields = ("hash", "archive_hash", "size", )


class DatasetSetInLine(admin.StackedInline):
    model = DatasetSet


@admin.register(Dataset)
class DatasetAdmin(admin.ModelAdmin):
    list_display = ("name", "corpus", "state", "unique_elements")
    list_filter = (("state", EnumFieldListFilter), "corpus")
    search_fields = ("name", "description")
    fields = ("id", "name", "created", "updated", "description", "corpus", "creator", "task", "unique_elements")
    readonly_fields = ("id", "created", "updated", "task")
    inlines = [DatasetSetInLine, ]

    def get_form(self, request, obj=None, **kwargs):
        # Prevent editing the `unique_elements` attribute
        self.readonly_fields = self.__class__.readonly_fields
        if obj is not None:
            self.readonly_fields += ("unique_elements",)
        return super().get_form(request, obj=None, **kwargs)
