# Generated by Django 4.1.7 on 2023-05-29 11:49

import uuid

import django.core.validators
import django.db.models.deletion
import enumfields.fields
from django.conf import settings
from django.contrib.postgres.operations import CreateCollation
from django.db import migrations, models
from enumfields import Enum


class OAuthStatus(Enum):
    Created = "created"
    Done = "done"
    Error = "error"


class Scope(Enum):
    UploadS3Image = "upload_s3_image"
    CreateIIIFImage = "create_iiif_image"
    S3Ingest = "s3_ingest"
    CreateDockerWorkerVersion = "create_docker_worker_version"


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("documents", "0002_initial"),
        ("contenttypes", "0002_remove_content_type_name"),
    ]

    operations = [
        CreateCollation(
            "case_insensitive",
            provider="icu",
            locale="und-u-ks-level2",
            deterministic=False,
        ),
        migrations.CreateModel(
            name="User",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("password", models.CharField(max_length=128, verbose_name="password")),
                ("last_login", models.DateTimeField(blank=True, null=True, verbose_name="last login")),
                ("email", models.EmailField(db_collation="case_insensitive", max_length=255, verbose_name="email address")),
                ("display_name", models.CharField(max_length=120)),
                ("transkribus_email", models.EmailField(blank=True, max_length=255, null=True)),
                ("is_active", models.BooleanField(default=True)),
                ("is_admin", models.BooleanField(default=False)),
                ("verified_email", models.BooleanField(default=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("selected_elements", models.ManyToManyField(related_name="selection_users", through="documents.Selection", to="documents.element")),
            ],
        ),
        migrations.CreateModel(
            name="Group",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=64)),
                ("public", models.BooleanField(default=False)),
                ("use_in_new_project", models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name="Right",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("content_id", models.UUIDField(editable=False)),
                ("level", models.PositiveIntegerField(help_text="Maximum privilege level.", validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(100)])),
                ("content_type", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="contenttypes.contenttype")),
                ("group", models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name="rights", to="users.group")),
                ("user", models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name="rights", to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name="OAuthCredentials",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("provider_url", models.URLField()),
                ("status", enumfields.fields.EnumField(default="created", enum=OAuthStatus, max_length=10)),
                ("token", models.CharField(blank=True, max_length=64, null=True)),
                ("refresh_token", models.CharField(blank=True, max_length=64, null=True)),
                ("expiry", models.DateTimeField(blank=True, null=True)),
                ("account_name", models.CharField(blank=True, max_length=100, null=True)),
                ("user", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="credentials", to=settings.AUTH_USER_MODEL)),
            ],
            options={
                "verbose_name": "OAuth credentials",
                "verbose_name_plural": "OAuth credentials",
            },
        ),
        migrations.CreateModel(
            name="UserScope",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("scope", enumfields.fields.EnumField(enum=Scope, max_length=50)),
                ("user", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="user_scopes", to=settings.AUTH_USER_MODEL)),
            ],
            options={
                "unique_together": {("user", "scope")},
            },
        ),
        migrations.AddConstraint(
            model_name="right",
            constraint=models.CheckConstraint(condition=models.Q(models.Q(("group_id__isnull", False), ("user_id__isnull", True)), models.Q(("group_id__isnull", True), ("user_id__isnull", False)), _connector="OR"), name="user_xor_group"),
        ),
        migrations.AddConstraint(
            model_name="right",
            constraint=models.UniqueConstraint(condition=models.Q(("user__isnull", False)), fields=("user", "content_id", "content_type"), name="right_user_unique_target"),
        ),
        migrations.AddConstraint(
            model_name="right",
            constraint=models.UniqueConstraint(condition=models.Q(("group__isnull", False)), fields=("group", "content_id", "content_type"), name="right_group_unique_target"),
        ),
        migrations.AddConstraint(
            model_name="user",
            constraint=models.UniqueConstraint(fields=("email",), name="email_unique"),
        ),
    ]
